using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Net;

using Smdn.Net.Imap4;
using Smdn.Net.Imap4.Client;

namespace Smdn.Applications.SimpleMailer {
  public class ImapAccount : AccountBase {
    public ImapClient Client {
      get { return client; }
    }

    public bool ReadOnly {
      get; private set;
    }

    public ImapAccount(string name,
                       Uri serverUri,
                       ICredentialsByHost credential,
                       int timeout,
                       bool useTlsIfAvailable,
                       bool readOnly,
                       ISynchronizeInvoke synchronizingObject)
      : base(name, serverUri)
    {
      this.client = new ImapClient(serverUri);
      this.client.SynchronizingObject = synchronizingObject;
      this.credential = credential;

      this.client.Profile.Timeout = timeout;
      this.client.Profile.UseTlsIfAvailable = useTlsIfAvailable;

      this.ReadOnly = readOnly;
    }

    public override void EnsureConnected()
    {
      if (client.IsConnected)
        return;

      client.Connect(credential);

      this.credential = null;
    }

    private ImapClient client;
    private ICredentialsByHost credential;
  }
}
